@@ -8,13 +8,16 @@
 #include <math.h>
 #include <signal.h>
 
+#define __STDC_FORMAT_MACROS
+#include <inttypes.h>
+
 #include <string>
 using namespace std;
 
 #include <xine.h>
 #include <xine/vdr.h>
 
-#define MIN_XINE_VDR_VERSION 802
+#define MIN_XINE_VDR_VERSION 901
 
 #if !defined(XINE_VDR_VERSION) || XINE_VDR_VERSION < MIN_XINE_VDR_VERSION
 #error xine/vdr.h does not match. Please solve this issue by reading section XINE VDR VERSION MISMATCH in INSTALL!
