@@ -146,11 +146,11 @@ namespace PluginXine
     virtual int64_t GetSTC(void);
     
 #if APIVERSNUM < 10307
-    virtual cOsdBase *NewOsd(int x, int y);
+    virtual cOsdBase *NewOsd(int w, int h, int x, int y);
 #elif APIVERSNUM < 10509
-    virtual cOsd *NewOsd(int x, int y);
+    virtual cOsd *NewOsd(int w, int h, int x, int y);
 #else    
-    virtual cOsd *NewOsd(int x, int y, uint Level, bool TrueColor = false);
+    virtual cOsd *NewOsd(int w, int h, int x, int y, uint Level, bool TrueColor = false);
 #endif
     bool ChangeCurrentOsd(cXineOsd *osd, bool on);
     
@@ -183,6 +183,11 @@ namespace PluginXine
     {
       return m_xineLib.hasNoSignalStream();
     }
+
+    bool SupportsTrueColorOSD() const
+    {
+      return m_xineLib.SupportsTrueColorOSD();
+    }
   };
 
 };
