@@ -44,8 +44,72 @@ namespace PluginXine
 #endif
 #endif
     },
-    { "Live-TV buffer [frames]",
-      "Puffer fr Live-TV [Bilder]",
+    { "Live-TV SD video buffer [frames]",
+      "SD-Video Puffer fr Live-TV [Bilder]",
+      "",// TODO
+      "Buffer TV dal vivo [frames]",
+      "Live-TV buffer [frames]",
+      "",// TODO
+      "",// TODO
+      "",// TODO
+      "TV-lhetyksen puskurointi [ruutua]",
+      "",// TODO
+      "",// TODO
+      "",// TODO
+      "Live-TV bufferstorlek [bildrutor]",
+      "",// TODO
+      "",// TODO
+      "",// TODO
+#if APIVERSNUM >= 10302
+      "",// TODO
+#if APIVERSNUM >= 10307
+      "",// TODO
+#if APIVERSNUM >= 10313
+      "",// TODO
+#if APIVERSNUM >= 10316
+      "",// TODO
+#if APIVERSNUM >= 10342
+      "",// TODO
+#endif
+#endif
+#endif
+#endif
+#endif
+    },    
+    { "Live-TV HD video buffer [frames]",
+      "HD-Video Puffer fr Live-TV [Bilder]",
+      "",// TODO
+      "Buffer TV dal vivo [frames]",
+      "Live-TV buffer [frames]",
+      "",// TODO
+      "",// TODO
+      "",// TODO
+      "TV-lhetyksen puskurointi [ruutua]",
+      "",// TODO
+      "",// TODO
+      "",// TODO
+      "Live-TV bufferstorlek [bildrutor]",
+      "",// TODO
+      "",// TODO
+      "",// TODO
+#if APIVERSNUM >= 10302
+      "",// TODO
+#if APIVERSNUM >= 10307
+      "",// TODO
+#if APIVERSNUM >= 10313
+      "",// TODO
+#if APIVERSNUM >= 10316
+      "",// TODO
+#if APIVERSNUM >= 10342
+      "",// TODO
+#endif
+#endif
+#endif
+#endif
+#endif
+    },    
+    { "Live-TV audio buffer [frames]",
+      "Audio Puffer fr Live-TV [Bilder]",
       "",// TODO
       "Buffer TV dal vivo [frames]",
       "Live-TV buffer [frames]",
