@@ -20,6 +20,7 @@ typedef pid_t tThreadId;
 #else
 
 #include <vdr/osd.h>
+
 #define  MAXNUMWINDOWS MAXOSDAREAS
 
 #endif
@@ -79,6 +80,81 @@ namespace PluginXine
  
   class cXineOsd;
   class cXineSettings;
+
+  class cXineAdapter
+  {
+  public:
+    virtual int X0(void) const = 0;
+    virtual int Y0(void) const = 0;
+    virtual int Width(void) const = 0;
+    virtual int Height(void) const = 0;
+    virtual bool Dirty(int &x1, int &y1, int &x2, int &y2) = 0;
+    virtual void Clean(void) = 0;
+    virtual const tColor *Colors(int &NumColors) const = 0;
+    virtual const uint8_t *Data(int x, int y) const = 0;
+    virtual int SizeOfPixel() const = 0;
+    virtual int SizeOfStride() const = 0;
+   };
+
+  class cXineBitmapAdapter : public cXineAdapter
+  {
+    cBitmap *const m_pBitmap;
+
+  public:
+    cXineBitmapAdapter(cBitmap *const pBitmap)
+      : m_pBitmap(pBitmap)
+    {
+    }
+
+    virtual int X0(void) const;
+    virtual int Y0(void) const;
+    virtual int Width(void) const;
+    virtual int Height(void) const;
+    virtual bool Dirty(int &x1, int &y1, int &x2, int &y2);
+    virtual void Clean(void);
+    virtual const tColor *Colors(int &NumColors) const;
+    virtual const uint8_t *Data(int x, int y) const;
+    virtual int SizeOfPixel() const;
+    virtual int SizeOfStride() const;
+
+    operator cXineAdapter *()
+    {
+      if (m_pBitmap)
+        return this;
+
+      return 0;
+    }
+  };
+
+#if APIVERSNUM >= 10717
+  
+  class cXinePixmapMemoryAdapter : public cXineAdapter
+  {
+    cPixmapMemory *const m_pPixmapMemory;
+
+  public:
+    cXinePixmapMemoryAdapter(const cPixmapMemory *const pPixmapMemory);
+    virtual int X0(void) const;
+    virtual int Y0(void) const;
+    virtual int Width(void) const;
+    virtual int Height(void) const;
+    virtual bool Dirty(int &x1, int &y1, int &x2, int &y2);
+    virtual void Clean(void);
+    virtual const tColor *Colors(int &NumColors) const;
+    virtual const uint8_t *Data(int x, int y) const;
+    virtual int SizeOfPixel() const;
+    virtual int SizeOfStride() const;
+
+    operator cXineAdapter *()
+    {
+      if (m_pPixmapMemory)
+        return this;
+
+      return 0;
+    }
+  };
+
+#endif
   
   class cXineLib : public cThread
   {
@@ -138,16 +214,16 @@ namespace PluginXine
     bool m_osdWindowSupportTransparency[ MAXNUMWINDOWS ];
 
     int m_osdWindowBufferSize[ MAXNUMWINDOWS ];
-    tIndex *m_osdWindowBuffer[ MAXNUMWINDOWS ];
-    
+    uint8_t *m_osdWindowBuffer[ MAXNUMWINDOWS ];
+
     tArea m_vidWin;
 #endif    
 
     result_query_capabilities_t m_capabilities;
 
-    void cloneBitmap(const int windowNum, cBitmap *bitmap, int x1, int y1, int x2, int y2);
-    bool bitmapDiffers(const int windowNum, cXineOsd *xineOsd, cBitmap *bitmap, int &x1, int &y1, int &x2, int &y2, const int osdX, const int osdY, const int osdW, const int osdH); 
-    bool clipBitmap(cXineOsd *xineOsd, cBitmap *bitmap, int &x1, int &y1, int &x2, int &y2, const int osdX, const int osdY, const int osdW, const int osdH); 
+    void cloneBitmap(const int windowNum, cXineAdapter *bitmap, int x1, int y1, int x2, int y2);
+    bool bitmapDiffers(const int windowNum, cXineOsd *xineOsd, cXineAdapter *bitmap, int &x1, int &y1, int &x2, int &y2, const int osdX, const int osdY, const int osdW, const int osdH); 
+    bool clipBitmap(cXineOsd *xineOsd, cXineAdapter *bitmap, int &x1, int &y1, int &x2, int &y2, const int osdX, const int osdY, const int osdW, const int osdH); 
     
     bool m_osdFlushRequired;
 
@@ -209,6 +285,8 @@ namespace PluginXine
         && m_noSignalStreamSize[1] > 0;
     }
 
+    bool SupportsTrueColorOSD() const;
+
     void selectNoSignalStream(const bool stream16x9)
     {
       m_noSignalStream16x9 = stream16x9;
@@ -245,11 +323,11 @@ namespace PluginXine
 
 #else
 
-void sendWindow(const int maxOsdWidth, const int maxOsdHeight, cXineOsd *const xineOsd, const int windowNum, cBitmap *bitmap = 0, const int videoLeft = -1, const int videoTop = -1, const int videoWidth = -1, const int videoHeight = -1, const int videoZoomX = -1, const int videoZoomY = -1, const bool dontOptimize = false);
-    void SendWindow(const int maxOsdWidth, const int maxOsdHeight, cXineOsd *const xineOsd, const int windowNum, cBitmap *bitmap = 0, const int videoLeft = -1, const int videoTop = -1, const int videoWidth = -1, const int videoHeight = -1, const int videoZoomX = -1, const int videoZoomY = -1, const bool dontOptimize = false);
+    void sendWindow(const int maxOsdWidth, const int maxOsdHeight, cXineOsd *const xineOsd, const int windowNum, cXineAdapter *bitmap = 0, const int videoLeft = -1, const int videoTop = -1, const int videoWidth = -1, const int videoHeight = -1, const int videoZoomX = -1, const int videoZoomY = -1, const bool dontOptimize = false);
+    void SendWindow(const int maxOsdWidth, const int maxOsdHeight, cXineOsd *const xineOsd, const int windowNum, cXineAdapter *bitmap = 0, const int videoLeft = -1, const int videoTop = -1, const int videoWidth = -1, const int videoHeight = -1, const int videoZoomX = -1, const int videoZoomY = -1, const bool dontOptimize = false);
     
     bool execFuncOsdNew(const int maxOsdWidth, const int maxOsdHeight, const eNeedsScaling needsScaling, const int videoLeft, const int videoTop, const int videoWidth, const int videoHeight, int window, int x, int y, int width, int height);
-    bool execFuncOsdDrawBitmap(const int maxOsdWidth, const int maxOsdHeight, const eNeedsScaling needsScaling, const int videoWidth, const int videoHeight, cXineOsd *const xineOsd, int window, cBitmap *const bitmap, int x, int y, int width, int height, int stride);
+    bool execFuncOsdDrawBitmap(const int maxOsdWidth, const int maxOsdHeight, const eNeedsScaling needsScaling, const int videoWidth, const int videoHeight, cXineOsd *const xineOsd, int window, cXineAdapter *const bitmap, int x, int y, int width, int height, int stride);
 
     void SetVideoWindow(const int maxOsdWidth, const int maxOsdHeight, tArea vidWin, const bool dontOptimize = false);
     
@@ -270,7 +348,7 @@ void sendWindow(const int maxOsdWidth, const int maxOsdHeight, cXineOsd *const x
     bool execFuncOsdShow(int window);
     bool execFuncOsdHide(int window);
     bool execFuncOsdSetPosition(int window, int x, int y);
-    bool execFuncOsdDrawBitmap(int window, const tIndex *const bitmap, int x, int y, int width, int height, int stride, const tColor *const colors);
+    bool execFuncOsdDrawBitmap(int window, const uint8_t *const bitmap, const int sizeOfPixel, int x, int y, int width, int height, int stride, const tColor *const colors);
 
 #if APIVERSNUM < 10307
     bool execFuncSetColor(int window, int index, eDvbColor color);
