@@ -9,12 +9,11 @@
 
 namespace PluginXine
 {
-
 #if APIVERSNUM < 10307
   
   bool cXineOsd::OpenWindow(cWindow *Window)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     
     m_windowVisible[ Window->Handle() ] = false;
     
@@ -26,14 +25,14 @@ namespace PluginXine
 
   void cXineOsd::CommitWindow(cWindow *Window)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     
     m_xineLib.CommitWindow(this, Window);
   }
 
   void cXineOsd::ShowWindow(cWindow *Window)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     
     m_windowVisible[ Window->Handle() ] = true;
     
@@ -42,7 +41,7 @@ namespace PluginXine
 
   void cXineOsd::HideWindow(cWindow *Window, bool Hide)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     
     m_windowVisible[ Window->Handle() ] = !Hide;
     
@@ -51,14 +50,14 @@ namespace PluginXine
 
   void cXineOsd::MoveWindow(cWindow *Window, int x, int y)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     
     m_xineLib.MoveWindow(this, Window, x, y);
   }
 
   void cXineOsd::CloseWindow(cWindow *Window)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     
     m_windowVisible[ Window->Handle() ] = false;
     
@@ -73,7 +72,7 @@ namespace PluginXine
   
   void cXineOsd::ReshowCurrentOsd(const bool dontOptimize, const int frameLeft /* = -1 */, const int frameTop /* = -1 */, const int frameWidth /* = -1 */, const int frameHeight /* = -1 */, const int frameZoomX /* = -1 */, const int frameZoomY /* = -1 */)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     
     int maxOsdWidth, maxOsdHeight;
     GetMaxOsdSize(maxOsdWidth, maxOsdHeight);
@@ -137,19 +136,17 @@ namespace PluginXine
     vh = videoHeight;
     zx = videoZoomX;
     zy = videoZoomY;
-    
-    for (int i = 0; i < MAXNUMWINDOWS; i++)
-      m_xineLib.SendWindow(maxOsdWidth, maxOsdHeight, this, i, GetBitmap(i), videoLeft, videoTop, videoWidth, videoHeight, videoZoomX, videoZoomY, dontOptimize);
-
+   
+    callSendWindow(maxOsdWidth, maxOsdHeight, videoLeft, videoTop, videoWidth, videoHeight, videoZoomX, videoZoomY, dontOptimize);
 #endif
 
     m_xineLib.execFuncOsdFlush();
   }
 
 #if APIVERSNUM < 10509
-  cXineOsd::cXineOsd(cXineDevice &xineDevice, int x, int y)
+  cXineOsd::cXineOsd(cXineDevice &xineDevice, int w, int h, int x, int y)
 #else
-  cXineOsd::cXineOsd(cXineDevice &xineDevice, int x, int y, uint Level)
+  cXineOsd::cXineOsd(cXineDevice &xineDevice, int w, int h, int x, int y, uint Level)
 #endif
 #if APIVERSNUM < 10307    
     : cOsdBase(x, y)
@@ -161,15 +158,18 @@ namespace PluginXine
     , m_xineDevice(xineDevice)
     , m_xineLib(xineDevice.m_xineLib)
     , m_osdMutex(xineDevice.m_osdMutex)
+    , m_extentWidth(w)
+    , m_extentHeight(h)
+#if APIVERSNUM >= 10717
+    , m_pRawOsd(0)
+#endif
   {
 //static int cnt = 0;
 //fprintf(stderr, "x: %d, y: %d, cnt: %d\n", x, y, cnt);
 //    if (x == 58 && y == 46 && cnt++ == 5) { char cmd[500]; sprintf(cmd, "ddd /soft/vdr-" APIVERSION "/bin/vdr %d", getpid()); system(cmd); sleep(10); } //should never happen!
 
 #if APIVERSNUM < 10307    
-
     ::memset(m_windowVisible, 0, sizeof (m_windowVisible));
-
 #endif
   }
 
@@ -178,16 +178,19 @@ namespace PluginXine
 #if APIVERSNUM < 10509
     HideOsd();
 #else
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     
     if (Active())
       SetActive(false);
+#endif
+#if APIVERSNUM >= 10717
+    delete m_pRawOsd;
 #endif
   }
 
   void cXineOsd::HideOsd()
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     
 #if APIVERSNUM < 10307    
 
@@ -220,8 +223,60 @@ namespace PluginXine
 //    m_xineLib.execFuncGrabImage("/tmp/grab.jpg", true, 50, 1000, 1000);
   }
 
+#if APIVERSNUM >= 10307
+
+  void cXineOsd::SetActive(bool On)
+  {
+#if APIVERSNUM >= 10509
+
+    cXineOsdMutexLock osdLock(&m_osdMutex);
+    
+    if (On == Active())
+      return;
+
+    cOsd::SetActive(On);
+
+    if (!m_xineDevice.ChangeCurrentOsd(this, On))
+      return;
+
+    if (On)
+      m_xineLib.ReshowCurrentOSD();
+    else
+      HideOsd();
+
+#endif    
+  }
+
+#endif
+
+#if APIVERSNUM >= 10717
+
+  cPixmap *cXineOsd::CreatePixmap(int Layer, const cRect &ViewPort, const cRect &DrawPort /* = cRect::Null */)
+  {
+    cXineOsdMutexLock osdLock(&m_osdMutex);
+    return cOsd::CreatePixmap(Layer, ViewPort, DrawPort);
+  }
+
+  void cXineOsd::DestroyPixmap(cPixmap *Pixmap)
+  {
+    cXineOsdMutexLock osdLock(&m_osdMutex);
+    cOsd::DestroyPixmap(Pixmap);
+  }
+
+  void cXineOsd::DrawImage(const cPoint &Point, const cImage &Image)
+  {
+    cXineOsdMutexLock osdLock(&m_osdMutex);
+    cOsd::DrawImage(Point, Image);
+  }
+
+  void cXineOsd::DrawImage(const cPoint &Point, int ImageHandle)
+  {
+    cXineOsdMutexLock osdLock(&m_osdMutex);
+    cOsd::DrawImage(Point, ImageHandle);
+  }
+
+#endif
 
-  
 #if APIVERSNUM >= 10307
   
   eOsdError cXineOsd::CanHandleAreas(const tArea *Areas, int NumAreas)
@@ -251,7 +306,10 @@ namespace PluginXine
           && 2 != a.bpp
           && 4 != a.bpp
           && 8 != a.bpp
-          && 16 != a.bpp)
+#if APIVERSNUM >= 10717
+          && (32 != a.bpp || !m_xineDevice.SupportsTrueColorOSD())
+#endif
+          )
       {
         return oeBppNotSupported;
       }
@@ -262,125 +320,85 @@ namespace PluginXine
 
   eOsdError cXineOsd::SetAreas(const tArea *Areas, int NumAreas)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     return cOsd::SetAreas(Areas, NumAreas);
   }
   
   void cXineOsd::SaveRegion(int x1, int y1, int x2, int y2)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     cOsd::SaveRegion(x1, y1, x2, y2);
   }
   
   void cXineOsd::RestoreRegion(void)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     cOsd::RestoreRegion();
   }
   
   eOsdError cXineOsd::SetPalette(const cPalette &Palette, int Area)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     return cOsd::SetPalette(Palette, Area);
   }
   
   void cXineOsd::DrawPixel(int x, int y, tColor Color)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     cOsd::DrawPixel(x, y, Color);
   }
   
 #if APIVERSNUM < 10327    
   void cXineOsd::DrawBitmap(int x, int y, const cBitmap &Bitmap, tColor ColorFg /* = 0 */, tColor ColorBg /* = 0 */)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     cOsd::DrawBitmap(x, y, Bitmap, ColorFg, ColorBg);
 //    fprintf(stderr, "drawbitmap\n");
   }
 #elif APIVERSNUM < 10344
   void cXineOsd::DrawBitmap(int x, int y, const cBitmap &Bitmap, tColor ColorFg /* = 0 */, tColor ColorBg /* = 0 */, bool ReplacePalette /* = false */)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     cOsd::DrawBitmap(x, y, Bitmap, ColorFg, ColorBg, ReplacePalette);
 //    fprintf(stderr, "drawbitmap\n");
   }
 #else  
   void cXineOsd::DrawBitmap(int x, int y, const cBitmap &Bitmap, tColor ColorFg /* = 0 */, tColor ColorBg /* = 0 */, bool ReplacePalette /* = false */, bool Overlay /* = false */)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     cOsd::DrawBitmap(x, y, Bitmap, ColorFg, ColorBg, ReplacePalette, Overlay);
 //    fprintf(stderr, "drawbitmap: (%d x %d) at (%d, %d) in (%d x %d)\n", Bitmap.Width(), Bitmap.Height(), x, y, Width(), Height());
   }
 #endif
 
-  void cXineOsd::DrawBitmapHor(int x, int y, int w, const cBitmap &Bitmap)
-  {
-#ifdef VDR_HAS_TRUECOLOR_OSD
-    cMutexLock osdLock(&m_osdMutex);
-    cOsd::DrawBitmapHor(x, y, w, Bitmap);
-#endif
-  }
-
-  void cXineOsd::DrawBitmapVert(int x, int y, int h, const cBitmap &Bitmap)
-  {
-#ifdef VDR_HAS_TRUECOLOR_OSD
-    cMutexLock osdLock(&m_osdMutex);
-    cOsd::DrawBitmapVert(x, y, h, Bitmap);
-#endif
-  }
-
   void cXineOsd::DrawText(int x, int y, const char *s, tColor ColorFg, tColor ColorBg, const cFont *Font, int Width /* = 0 */, int Height /* = 0 */, int Alignment /* = taDefault */)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     cOsd::DrawText(x, y, s, ColorFg, ColorBg, Font, Width, Height, Alignment);
   }
   
-  void cXineOsd::DrawImage(u_int imageId, int x, int y, bool blend, int horRepeat /* = 1 */, int vertRepeat /* = 1 */)
-  {
-#ifdef VDR_HAS_TRUECOLOR_OSD
-    cMutexLock osdLock(&m_osdMutex);
-    cOsd::DrawImage(imageId, x, y, blend, horRepeat, vertRepeat);
-#endif
-  }
-
   void cXineOsd::DrawRectangle(int x1, int y1, int x2, int y2, tColor Color)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     cOsd::DrawRectangle(x1, y1, x2, y2, Color);
   }
   
-  void cXineOsd::DrawRectangle(int x1, int y1, int x2, int y2, tColor Color, int alphaGradH, int alphaGradV, int alphaGradStepH, int alphaGradStepV)
-  {
-#ifdef VDR_HAS_TRUECOLOR_OSD
-    cMutexLock osdLock(&m_osdMutex);
-    cOsd::DrawRectangle(x1, y1, x2, y2, Color, alphaGradH, alphaGradV, alphaGradStepH, alphaGradStepV);
-#endif
-  }
-
   void cXineOsd::DrawEllipse(int x1, int y1, int x2, int y2, tColor Color, int Quadrants /* = 0 */)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     cOsd::DrawEllipse(x1, y1, x2, y2, Color, Quadrants);
   }
   
   void cXineOsd::DrawSlope(int x1, int y1, int x2, int y2, tColor Color, int Type)
   {
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
     cOsd::DrawSlope(x1, y1, x2, y2, Color, Type);
   }
   
-  void cXineOsd::SetImagePath(u_int imageId, char const *path)
-  {
-#ifdef VDR_HAS_TRUECOLOR_OSD
-    cMutexLock osdLock(&m_osdMutex);
-    cOsd::SetImagePath(imageId, path);
-#endif
-  }
-
   void cXineOsd::Flush(void)
   {
 //    ::fprintf(stderr, "Flush ---: %s\n", ::ctime(&(const time_t &)::time(0)));
-    cMutexLock osdLock(&m_osdMutex);
+    cXineOsdMutexLock osdLock(&m_osdMutex);
 //    ::fprintf(stderr, "Flush +++: %s\n", ::ctime(&(const time_t &)::time(0)));
 #if APIVERSNUM >= 10509
     if (!Active())
@@ -429,15 +447,117 @@ namespace PluginXine
       zx = videoZoomX;
       zy = videoZoomY;
     }
-    
-    for (int i = 0; i < MAXNUMWINDOWS; i++)
-      m_xineLib.SendWindow(maxOsdWidth, maxOsdHeight, this, i, GetBitmap(i), videoLeft, videoTop, videoWidth, videoHeight, videoZoomX, videoZoomY);
+
+    callSendWindow(maxOsdWidth, maxOsdHeight, videoLeft, videoTop, videoWidth, videoHeight, videoZoomX, videoZoomY);
 
     m_xineLib.execFuncOsdFlush();
   }
 
+  void cXineOsd::callSendWindow(const int maxOsdWidth, const int maxOsdHeight, const int videoLeft, const int videoTop, const int videoWidth, const int videoHeight, const int videoZoomX, const int videoZoomY, const bool dontOptimize /* = false */)
+  {
+#if APIVERSNUM >= 10717
+bool head = false;
+    if (IsTrueColor())
+    {
+      if (m_pRawOsd)
+      {
+        if (m_pRawOsd->DrawPort().Width() != Width()
+          || m_pRawOsd->DrawPort().Height() != Height())
+        {
+          delete m_pRawOsd;
+          m_pRawOsd = 0;
+        }
+      }
+
+      if (!m_pRawOsd)
+      {
+        m_pRawOsd = new cPixmapMemory(0, cRect(0, 0, Width(), Height()));
+        m_pRawOsd->Clear();
+if (!head)
+{
+  head = true;
+//  fprintf(stderr, "OSD: -c-c-c-c-c-c-c-c-c-c-c-c-c-c-c-c-c-c-c-c-c-c-c-c-c\n");
+}
+      }
+
+      while (cPixmapMemory *pm = RenderPixmaps())
+      {
+if (!head)
+{
+  head = true;
+//  fprintf(stderr, "OSD: --------------------------------------------------\n");
+}
+/*
+  fprintf(stderr, "OSD: X: %4d, Y: %4d, W: %4d, H: %4d, X: %4d, Y: %4d, W: %4d, H: %4d\n"
+, pm->ViewPort().X()
+, pm->ViewPort().Y()
+, pm->ViewPort().Width()
+, pm->ViewPort().Height()
+, pm->DrawPort().X()
+, pm->DrawPort().Y()
+, pm->DrawPort().Width()
+, pm->DrawPort().Height()
+);
+*/
+        m_pRawOsd->Copy(pm, pm->DrawPort().Shifted(-pm->DrawPort().Point()), pm->ViewPort().Point());
+        delete pm; 
+      }
+    }
+    else if (m_pRawOsd)
+    {
+      delete m_pRawOsd;
+      m_pRawOsd = 0;
+/*
+if (head)
+  fprintf(stderr, "OSD: =d=d=d=d=d=d=d=d=d=d=d=d=d=d=d=d=d=d=d=d=d=d=d=d=d\n");
+*/
+    }
+
+    if (m_pRawOsd)
+    {
+      cXinePixmapMemoryAdapter adapter(m_pRawOsd);
+/*
+cXineAdapter *bm = adapter;
+int x0, y0, x1, y1;
+bool d = bm->Dirty(x0, y0, x1, y1);
+if (head)
+  fprintf(stderr, d ? "OSD: x: %4d, y: %4d, w: %4d, h: %4d, x0: %4d, y0: %4d, x1: %4d, y1: %4d\n" : "OSD: x: %4d, y: %4d, w: %4d, h: %4d\n"
+, bm->X0()
+, bm->Y0()
+, bm->Width()
+, bm->Height()
+, x0
+, y0
+, x1
+, y1
+);
+*/
+      m_xineLib.SendWindow(maxOsdWidth, maxOsdHeight, this, 0, adapter, videoLeft, videoTop, videoWidth, videoHeight, videoZoomX, videoZoomY, dontOptimize);
+
+      for (int i = 1; i < MAXNUMWINDOWS; i++)
+        m_xineLib.SendWindow(maxOsdWidth, maxOsdHeight, this, i);
+/*
+if (head)
+  fprintf(stderr, "OSD: ==================================================\n");
+*/
+    }
+    else
+#endif
+    {
+      for (int i = 0; i < MAXNUMWINDOWS; i++)
+      {
+        cXineBitmapAdapter adapter(GetBitmap(i));
+        m_xineLib.SendWindow(maxOsdWidth, maxOsdHeight, this, i, adapter, videoLeft, videoTop, videoWidth, videoHeight, videoZoomX, videoZoomY, dontOptimize);
+      }
+    }
+  }
+
   void cXineOsd::GetMaxOsdSize(int &maxOsdWidth, int &maxOsdHeight)
   {
+    maxOsdWidth  = m_extentWidth;
+    maxOsdHeight = m_extentHeight;
+    return;
+/*
     maxOsdWidth  = 0;
     maxOsdHeight = 0;
 
@@ -489,30 +609,34 @@ namespace PluginXine
       maxOsdWidth  = 720;
       maxOsdHeight = 576;
     }
+*/
   }
 
-  void cXineOsd::SetActive(bool On)
+
+
+  cXineOsdMutexLock::cXineOsdMutexLock(cMutex *const pOsdMutex)
+    : m_pOsdLock(0)
+#if APIVERSNUM >= 10717
+    , m_pPixmapMutexLock(0)
+#endif
   {
-#if APIVERSNUM >= 10509
-    cMutexLock osdLock(&m_osdMutex);
-    
-    if (On == Active())
-      return;
-
-    cOsd::SetActive(On);
-
-    if (!m_xineDevice.ChangeCurrentOsd(this, On))
-      return;
-
-    if (On)
-      m_xineLib.ReshowCurrentOSD();
-    else
-      HideOsd();
-#endif    
+#if APIVERSNUM >= 10717
+    m_pPixmapMutexLock = new cPixmapMutexLock;
+#endif
+    m_pOsdLock = new cMutexLock(pOsdMutex);
   }
 
-  
-  
+  cXineOsdMutexLock::~cXineOsdMutexLock()
+  {
+    delete m_pOsdLock;
+
+#if APIVERSNUM >= 10717
+    delete m_pPixmapMutexLock;
+#endif      
+  }
+
+
+
   cXineOsdProvider::cXineOsdProvider(cXineDevice &xineDevice)
     : cOsdProvider()
     , m_xineDevice(xineDevice)
@@ -522,17 +646,24 @@ namespace PluginXine
 #if APIVERSNUM < 10509  
   cOsd *cXineOsdProvider::CreateOsd(int Left, int Top)
   {
-    return m_xineDevice.NewOsd(Left, Top);
+    return m_xineDevice.NewOsd(0, 0, Left, Top);
   }
 #else
   cOsd *cXineOsdProvider::CreateOsd(int Left, int Top, uint Level)
   {
-    return m_xineDevice.NewOsd(Left, Top, Level);
+    return m_xineDevice.NewOsd(0, 0, Left, Top, Level);
   }
 
-  cOsd *cXineOsdProvider::CreateTrueColorOsd(int Left, int Top, uint Level)
+  cOsd *cXineOsdProvider::CreateOsd(int ExtentWidth, int ExtentHeight, int Left, int Top, uint Level)
   {
-    return m_xineDevice.NewOsd(Left, Top, Level, true);
+    return m_xineDevice.NewOsd(ExtentWidth, ExtentHeight, Left, Top, Level);
+  }
+#endif
+
+#if APIVERSNUM >= 10717
+  bool cXineOsdProvider::ProvidesTrueColor()
+  {
+    return true;
   }
 #endif
   
