@@ -65,6 +65,11 @@ namespace PluginXine
     kSubtitles,
 #else
     kNone,
+#endif
+#if APIVERSNUM >= 10715
+    kUser0,
+#else
+    kNone,
 #endif
   };
 
