@@ -14,9 +14,11 @@ namespace PluginXine
 {
 
   cXineSettings::cModeParams::cModeParams()
-    : m_prebufferFrames(4)
+    : m_prebufferFramesVideoSD(4)
+    , m_prebufferFramesVideoHD(4)
+    , m_prebufferFramesAudio(4)
     , m_prebufferHysteresis(4)
-    , m_monitoringDuration(60)
+    , m_monitoringDuration(10)
     , m_monitoringMode(monitoringOnce)
   {
   }
@@ -69,7 +71,20 @@ namespace PluginXine
 
     Name += prefixLen;
     
-    if (SetupParse("prebufferFrames", m_prebufferFrames, Name, Value))
+    if (SetupParse("prebufferFrames", m_prebufferFramesVideoSD, Name, Value)
+      && SetupParse("prebufferFrames", m_prebufferFramesVideoHD, Name, Value)
+      && SetupParse("prebufferFrames", m_prebufferFramesAudio, Name, Value))
+    {
+      return true;
+    }
+
+    if (SetupParse("prebufferFramesVideoSD", m_prebufferFramesVideoSD, Name, Value))
+      return true;
+
+    if (SetupParse("prebufferFramesVideoHD", m_prebufferFramesVideoHD, Name, Value))
+      return true;
+
+    if (SetupParse("prebufferFramesAudio", m_prebufferFramesAudio, Name, Value))
       return true;
 
     if (SetupParse("prebufferHysteresis", m_prebufferHysteresis, Name, Value))
@@ -135,8 +150,76 @@ namespace PluginXine
 
   bool cXineSettings::cZoomParams::operator !=(const cXineSettings::cZoomParams &rhs) const
   {
-    return m_zoomX != rhs.m_zoomX
-      || m_zoomY != rhs.m_zoomY;
+    return GetZoomX() != rhs.GetZoomX()
+      || GetZoomY() != rhs.GetZoomY();
+  }
+
+  
+  cXineSettings::cOsdExtentParams::cOsdExtentParams()
+    : m_osdExtentWidth(osdExtentWidthDefault)
+    , m_osdExtentHeight(osdExtentHeightDefault)
+  {
+  }
+  
+  bool cXineSettings::cOsdExtentParams::SetupParse(const char *optionName, eOsdExtentWidth &optionValue, const char *Name, const char *Value)
+  {
+    if (0 != ::strcasecmp(optionName, Name))
+      return false;
+
+    char c;
+    int v = 0;    
+    if (1 != ::sscanf(Value, "%d%c", &v, &c))
+      return false;
+
+    if (osdExtentWidthMin <= v && v <= osdExtentWidthMax)
+    {
+      optionValue = (eOsdExtentWidth)v;
+      return true;
+    }   
+    
+    return false;
+  }
+ 
+  bool cXineSettings::cOsdExtentParams::SetupParse(const char *optionName, eOsdExtentHeight &optionValue, const char *Name, const char *Value)
+  {
+    if (0 != ::strcasecmp(optionName, Name))
+      return false;
+
+    char c;
+    int v = 0;    
+    if (1 != ::sscanf(Value, "%d%c", &v, &c))
+      return false;
+
+    if (osdExtentHeightMin <= v && v <= osdExtentHeightMax)
+    {
+      optionValue = (eOsdExtentHeight)v;
+      return true;
+    }   
+    
+    return false;
+  }
+   bool cXineSettings::cOsdExtentParams::SetupParse(const char *prefix, const char *Name, const char *Value)
+  {
+    const int prefixLen = ::strlen(prefix);
+    
+    if (0 != ::strncasecmp(prefix, Name, prefixLen))
+      return false;
+
+    Name += prefixLen;
+    
+    if (SetupParse("X", m_osdExtentWidth, Name, Value))
+      return true;
+
+    if (SetupParse("Y", m_osdExtentHeight, Name, Value))
+      return true;
+
+    return false;
+  }
+
+  bool cXineSettings::cOsdExtentParams::operator !=(const cXineSettings::cOsdExtentParams &rhs) const
+  {
+    return GetOsdExtentWidth() != rhs.GetOsdExtentWidth()
+      || GetOsdExtentHeight() != rhs.GetOsdExtentHeight();
   }
 
   
@@ -428,6 +511,11 @@ namespace PluginXine
     if (SetupParse("osdGammaCorrection", m_crtGamma, Name, Value))
       return true;
 
+#if APIVERSNUM >= 10707
+    if (m_osdExtentParams.SetupParse("osdExtent.", Name, Value))
+      return true;
+#endif
+
 #if APIVERSNUM < 10318
     if (SetupParse("audioMode", m_audioMode, Name, Value))
       return true;
@@ -502,7 +590,9 @@ namespace PluginXine
     muteModes[ muteExecute ]  = tr("Execute");
     muteModes[ muteSimulate ] = tr("Simulate");
     
-    setupPage->Add(new cMenuEditIntItem(tr("Live-TV buffer [frames]"), &m_modeParams[ modeLiveTV ].m_prebufferFrames, 0, 50));
+    setupPage->Add(new cMenuEditIntItem(tr("Live-TV SD video buffer [frames]"), &m_modeParams[ modeLiveTV ].m_prebufferFramesVideoSD, 0, 50));
+    setupPage->Add(new cMenuEditIntItem(tr("Live-TV HD video buffer [frames]"), &m_modeParams[ modeLiveTV ].m_prebufferFramesVideoHD, 0, 50));
+    setupPage->Add(new cMenuEditIntItem(tr("Live-TV audio buffer [frames]"), &m_modeParams[ modeLiveTV ].m_prebufferFramesAudio, 0, 50));
 //    setupPage->Add(new cMenuEditIntItem(tr("Replay prebuffer [frames]"), &m_modeParams[ modeReplay ].m_prebufferFrames, 0, 50));
 //    setupPage->Add(new cMenuEditBoolItem(tr("Default settings optimized for"), (int *)&m_usageModeDefault, tr("Live-TV"), tr("Replay")));
     setupPage->Add(new cMenuEditIntItem(tr("Buffer hysteresis [frames]"), &m_modeParams[ modeLiveTV ].m_prebufferHysteresis, 0, 50));
@@ -510,6 +600,12 @@ namespace PluginXine
     setupPage->Add(new cMenuEditBoolItem(tr("Buffer monitoring mode"), &alias_cast<int>(m_modeParams[ modeLiveTV ].m_monitoringMode), tr("Once"), tr("Continuous")));
     setupPage->Add(new cMenuEditStraItem(tr("OSD display mode"), &alias_cast<int>(m_osdMode), sizeof (osdModes) / sizeof (*osdModes), osdModes));
     setupPage->Add(new cMenuEditIntItem(tr("OSD gamma correction [ 123 => 1.23 ]"), &alias_cast<int>(m_crtGamma), monitorGammaMin, monitorGammaMax));
+
+#if APIVERSNUM >= 10707
+    setupPage->Add(new cMenuEditIntItem(tr("OSD extent X"), &alias_cast<int>(m_osdExtentParams.m_osdExtentWidth), osdExtentWidthMin, osdExtentWidthMax));
+    setupPage->Add(new cMenuEditIntItem(tr("OSD extent Y"), &alias_cast<int>(m_osdExtentParams.m_osdExtentHeight), osdExtentHeightMin, osdExtentHeightMax));
+#endif
+
     setupPage->Add(new cMenuEditIntItem(tr("4:3 image zoom X [%]"), &alias_cast<int>(m_zoomParams[ image4_3 ].m_zoomX), imageZoomMin, imageZoomMax));
     setupPage->Add(new cMenuEditIntItem(tr("4:3 image zoom Y [%]"), &alias_cast<int>(m_zoomParams[ image4_3 ].m_zoomY), imageZoomMin, imageZoomMax));
     setupPage->Add(new cMenuEditIntItem(tr("16:9 image zoom X [%]"), &alias_cast<int>(m_zoomParams[ image16_9 ].m_zoomX), imageZoomMin, imageZoomMax));
@@ -526,7 +622,9 @@ namespace PluginXine
   
   void cXineSettings::Store(cXineSetupPage *const setupPage)
   {
-    setupPage->SetupStore("modeLiveTV.prebufferFrames", m_modeParams[ modeLiveTV ].m_prebufferFrames);
+    setupPage->SetupStore("modeLiveTV.prebufferFramesVideoSD", m_modeParams[ modeLiveTV ].m_prebufferFramesVideoSD);
+    setupPage->SetupStore("modeLiveTV.prebufferFramesVideoHD", m_modeParams[ modeLiveTV ].m_prebufferFramesVideoHD);
+    setupPage->SetupStore("modeLiveTV.prebufferFramesAudio", m_modeParams[ modeLiveTV ].m_prebufferFramesAudio);
 //    setupPage->SetupStore("modeReplay.prebufferFrames", m_modeParams[ modeReplay ].m_prebufferFrames);
 //    setupPage->SetupStore("usageModeDefault", (m_usageModeDefault ? "modeReplay" : "modeLiveTV"));
     setupPage->SetupStore("modeLiveTV.prebufferHysteresis", m_modeParams[ modeLiveTV ].m_prebufferHysteresis);
@@ -557,6 +655,12 @@ namespace PluginXine
     }
     
     setupPage->SetupStore("osdGammaCorrection", (int)m_crtGamma);
+
+#if APIVERSNUM >= 10707
+    setupPage->SetupStore("osdExtent.X", m_osdExtentParams.m_osdExtentWidth);
+    setupPage->SetupStore("osdExtent.Y", m_osdExtentParams.m_osdExtentHeight);
+#endif
+
 #if APIVERSNUM < 10318
     setupPage->SetupStore("audioMode", (m_audioMode ? "audioDolbyOn" : "audioDolbyOff"));
 #endif
